pub trait DmaAllocator { // Required methods fn alloc_dma(&self, size: usize) -> Result<DmaRegion, DmaAllocError>; unsafe fn free_dma(&self, region: DmaRegion); }
Allocates dma.
The caller must ensure that region was previously allocated by this allocator and has not already been freed.
region